# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu Sanity Tests
# Copyright (C) 2014 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import configparser
import os
import subprocess
import systemimage.config as sys_info
import time

from autopilot import introspection
from gi.repository import Click


def get_proxy_object_for_existing_process(
        process_name, base_custom_proxy_object):
    """Return the proxy object for a currently running process."""
    return introspection.get_proxy_object_for_existing_process(
        pid=_get_pid(process_name),
        emulator_base=base_custom_proxy_object
    )


# Pulled from the UX tests
def _get_pid(process_name):
    """Returns pid for currently running browser process."""
    for i in range(10):
        try:
            return int(
                subprocess.check_output(
                    ['pidof', process_name]).strip()
            )
        except subprocess.CalledProcessError:
            time.sleep(1)
    else:
        raise RuntimeError(
            'Could not find autopilot interface for {} after 10 '
            'seconds'.format(process_name)
        )


def get_device_name():
    return sys_info.config.device


def get_channel_name():
    parser = configparser.ConfigParser()
    parser.read('/etc/system-image/channel.ini')
    return parser['service']['channel']


def is_agps_supported():
    db = Click.DB()
    db.read()
    registry = Click.User.for_user(db, name=os.getenv('USER'))
    return registry.has_package_name('com.nokia.heremaps')
