# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu Sanity Tests
# Copyright (C) 2014, 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import ubuntuuitoolkit
from unity8.shell.emulators import dash


class Dash(dash.Dash):

    def wait_for_processing_to_complete(self):
        self.select_single(
            objectName='processingIndicator').visible.wait_for(False)


class GenericScopeView(dash.GenericScopeView):

    def click_scope_item(self, category, title, press_duration=0.10):
        category_element = self._get_category_element(category)
        icon = category_element.wait_select_single(
            'AbstractButton', title=title)
        list_view = self.select_single(
            ListViewWithPageHeader, objectName='categoryListView')
        list_view.swipe_child_into_view(icon)
        self.pointing_device.click_object(icon, press_duration=press_duration)

    def open_preview(self, category, app_name, press_duration=0.10):
        """Open the preview of an application.

        :parameter category: The name of the category where the application is.
        :parameter app_name: The name of the application.
        :return: The opened preview.

        """
        self.click_scope_item(category, app_name, press_duration)
        preview_list = self.wait_select_single(
            'QQuickLoader', objectName='subPageLoader')
        preview_list.subPageShown.wait_for(True)
        preview_list.x.wait_for(0)
        self.get_root_instance().select_single(
            objectName='processingIndicator').visible.wait_for(False)
        return preview_list.select_single(
            'Preview', objectName='preview{}'.format(
                preview_list.initialIndex))


class ListViewWithPageHeader(ubuntuuitoolkit.QQuickListView):

    def swipe_to_show_more_below(self, containers):
        # XXX overriden because the margin to start the swipe is bigger than
        # in the other apps. See bug http://pad.lv/1401517
        # --elopio - 2014-12-11
        if self.atYEnd:
            super().swipe_to_show_more_below(containers)
        else:
            start_x = stop_x = self.globalRect.x + (self.globalRect.width // 2)
            from ubuntuuitoolkit._custom_proxy_objects import _flickable
            start_y = _flickable._get_visible_container_bottom(containers) - 50
            stop_y = _flickable._get_visible_container_top(containers) + 5
            self._slow_drag(start_x, stop_x, start_y, stop_y)
            self.dragging.wait_for(False)
            self.moving.wait_for(False)
