# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu Sanity Tests
# Copyright (C) 2014, 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import logging

import fixtures
from autopilot import (
    introspection,
    logging as autopilot_logging,
    testcase
)
from ubuntuuitoolkit import fixture_setup

from unity8 import process_helpers
from unity8.shell import emulators
from unity8.shell.emulators import dash

from ubuntu_sanity_tests.helpers import unity8
from ubuntu_sanity_tests.helpers.unity8 import shell


logger = logging.getLogger(__name__)


class BaseUbuntuSanityTestCase(testcase.AutopilotTestCase):

    @classmethod
    def setUpClass(cls):
        unity8.ensure_unity_stopped()
        super().setUpClass()

    @classmethod
    def tearDownClass(cls):
        super().tearDownClass()
        unity8.ensure_unity_running_and_greeter_hidden()

    def setUp(self):
        super().setUp()
        # Mirscreencast fails if this environment variable is not set.
        # See http://pad.lv/1423359.
        self.useFixture(fixtures.EnvironmentVariable('LC_ALL', 'C'))

    @autopilot_logging.log_action(logger.info)
    def launch_unity(self):
        """Launch Unity8 with testability enabled.

        :return: The Unity8 autopiliot custom proxy object.

        """
        self.useFixture(
            fixture_setup.InitctlEnvironmentVariable(QT_LOAD_TESTABILITY='1'))
        process_helpers.start_job('unity8', 'QT_LOAD_TESTABILITY=1')
        pid = process_helpers.get_job_pid('unity8')
        unity = introspection.get_proxy_object_for_existing_process(
            pid=pid,
            emulator_base=shell.Unity8
        )
        unity.wait_for_greeter_content()
        return unity

    def get_dash(self):
        """Return the Unity8 Dash autopilot custom proxy object."""
        pid = process_helpers.get_job_pid('unity8-dash')
        dash_proxy = introspection.get_proxy_object_for_existing_process(
            pid=pid,
            emulator_base=emulators.UnityEmulatorBase,
        )
        dash_app = dash.DashApp(dash_proxy)
        return dash_app.dash
