# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu Sanity Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import subprocess

import address_book_app

from ubuntu_sanity_tests.tests import base
from ubuntu_sanity_tests.helpers import autopilot as autopilot_helpers
from ubuntu_sanity_tests.helpers.addressbook import (
    fixture_setup as addressbook_fixtures,
)
# Imported to load the custom proxy objects.
from ubuntu_sanity_tests.helpers import addressbook  # NOQA


class AddContactSanityTest(base.BaseUbuntuSanityTestCase):

    def setUp(self):
        super().setUp()
        unity_proxy = self.launch_unity()
        unity_proxy.unlock()
        self.useFixture(addressbook_fixtures.BackupContacts())

    def get_test_contact(self):
        first_name = 'Fulano'
        last_name = 'de Tal'
        mobile_number = address_book_app.data.Phone.make()
        return address_book_app.data.Contact(
            first_name=first_name, last_name=last_name,
            phones=[mobile_number])

    def launch_address_book(self, dash):
        apps_scope = dash.open_scope('clickscope')
        self.addCleanup(
            subprocess.check_call, ['ubuntu-app-stop', 'address-book-app'])
        apps_scope.click_scope_item('predefined', 'Contacts')
        return autopilot_helpers.get_proxy_object_for_existing_process(
            'address-book-app',
            address_book_app.AddressBookApp)

    def test_add_contact_with_name_and_number(self):
        test_contact = self.get_test_contact()
        test_contact_name = (
            test_contact.first_name + ' ' + test_contact.last_name)

        dash = self.get_dash()
        application = self.launch_address_book(dash)

        # Add new contact.
        contact_editor = application.main_window.go_to_add_contact()
        contact_editor.fill_form(test_contact)
        application.main_window.save()

        # Check that the contact was added.
        list_page = application.main_window.get_contact_list_page()
        contacts = list_page.get_contacts()
        self.assertIn(test_contact_name, contacts)

        # Check the contact details.
        contact_index = contacts.index(test_contact_name)
        list_page.expand_contact(contact_index)

        number = list_page.get_contact_mobile_phone_number(contact_index)
        self.assertEqual(number, test_contact.phones[0].number)
