# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Copyright (C) 2014, 2015 Canonical Ltd.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation; version 3.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import autopilot
import ubuntu_system_settings
from autopilot.matchers import Eventually
from testtools.matchers import Contains

import ubuntu_sanity_tests.helpers.unity8.dash  # NOQA
from ubuntu_sanity_tests.helpers import autopilot as autopilot_helpers
from ubuntu_sanity_tests.helpers.system_settings import(
    ensure_system_settings_closed)
from ubuntu_sanity_tests.tests import base


class BluetoothTestCase(base.BaseUbuntuSanityTestCase):

    def setUp(self):
        """ Go to Bluetooth page """
        super(BluetoothTestCase, self).setUp()
        unity_proxy = self.launch_unity()
        unity_proxy.unlock()

        dash = self.get_dash()
        apps_scope = dash.open_scope('clickscope')

        apps_scope.click_scope_item('local', 'System Settings')
        self.addCleanup(ensure_system_settings_closed)

        self.app = autopilot_helpers.get_proxy_object_for_existing_process(
            'system-settings', ubuntu_system_settings.SystemSettings)
        self.bluetooth_page = self.app.main_view.go_to_bluetooth_page()

    def test_discover_bluetooth_devices(self):
        """Discover Bluetooth devices.

        The test only runs if the 'bluetooth_device_name' option variable
        has been set

        """
        device_name = autopilot.get_test_configuration().get(
            'bluetooth_device_name', None)
        if device_name:
            self.assertThat(
                lambda: self.bluetooth_page.get_disconnected_devices(),
                Eventually(Contains(device_name), timeout=60)
            )
        else:
            self.skipTest('Bluetooth device not declared to be present')
